# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import click
import pastebot

click.disable_unicode_literals_warning = True
CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])


@click.group(context_settings=CONTEXT_SETTINGS)
@click.version_option(pastebot.__version__)
def main():
    pass


@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("--token", required=True, help="微博 access token")
@click.option("--dsn", default=None, help="sentry dsn")
@click.option("--pool", type=click.INT, default=10, help="线程池大小")
@click.option("--qps", type=click.FLOAT, default=1, help="qps")
@click.option("--timeout", type=click.FLOAT, default=5, help="请求 timeout")
def serve(token, dsn, pool, qps, timeout):
    """开始运行 pastebot"""
    pb = pastebot.PasteBot()
    pb.weibo_access_token = token
    pb.sentry_dsn = dsn

    if pool <= 0:
        raise click.BadParameter("线程池大小必须大于 0")
    pb.thread_pool_size = pool

    if qps <= 0:
        raise click.BadParameter("qps 必须大于 0")
    pb.qps = qps

    if timeout <= 0:
        raise click.BadParameter("timeout 必须大于 0")
    pb.request_timeout = timeout

    pb.start()


@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("--key", required=True, help="微博 App Key")
@click.option("--secret", required=True, help="微博 App Secret")
@click.option("--domain", required=True, help="微博安全域名")
def weibo(key, secret, domain):
    """生成 weibo access token"""
    wb = pastebot.WeiBo()
    wb.app_key = key
    wb.app_secret = secret
    wb.secure_domain = domain

    result = wb.exchange_access_token()

    click.echo('返回 access_token: {}'.format(result['access_token']))
    click.echo('过期时间: {}h'.format(int(result['expires_in']) / (60 * 60)))
    click.echo('用户 uid: {}'.format(result['uid']))



# -*- coding: utf-8 -*-

from __future__ import unicode_literals, division

import requests
import webbrowser


class WeiBo(object):
    def __init__(self):
        self.app_key = None
        self.app_secret = None
        self.secure_domain = None
        self.auth_code = None
        self.access_token = None
        self.sina_oauth2_authorize_url = 'https://api.weibo.com/oauth2/authorize?client_id={}&redirect_uri=http://{}'
        self.sina_oauth2_access_token_url = 'https://api.weibo.com/oauth2/access_token'
        self.sina_new_post_url = 'https://api.weibo.com/2/statuses/share.json'

    def exchange_auth_code(self):
        url = self.sina_oauth2_authorize_url.format(self.app_key, self.secure_domain)
        webbrowser.open(url)
        self.auth_code = input("input auth_code: ").strip()

    def exchange_access_token(self):
        if not self.auth_code:
            self.exchange_auth_code()

        data = {
            'client_id': self.app_key,
            'client_secret': self.app_secret,
            'grant_type': 'authorization_code',
            'code': self.auth_code,
            'redirect_uri': 'http://{}'.format(self.secure_domain)
        }

        rp = requests.post(self.sina_oauth2_access_token_url, data=data)
        result = rp.json()
        self.access_token = result['access_token']
        return result

    def new_post(self, post):
        if not self.access_token:
            self.exchange_access_token()

        data = {
            'access_token': self.access_token,
            "status": post
        }
        rp = requests.post(self.sina_new_post_url, data=data)
        return rp.text
